This function takes a dataframe of all the sign corrected scores, thus all negative, and aggregates to get a total sample quality score.
accumulate.zscores(zscores.corrected, filename = NULL)A dataframe of aggregated z-scores for each sample
Sample IDs defined by the rownames of zscores.corrected
Sum of z-scores
A dataframe whose rows are samples and each column a QC metric
A filename where to save data. If NULL data will not be saved to file