This function takes a dataframe of QC metrics, and calculates the the z-scores. If filename is specified, the results will be saved to file.
zscores.from.metrics(qc.data, filename = NULL)A dataframe of z-scores; rows correspond to samples and columns correspond to metrics from qc.data
A dataframe whose rows are samples and each column a QC metric
A filename where to save data. If NULL data will not be saved to file